import re
import hashlib
import pynliner

from email.MIMEImage import MIMEImage

from django.core.mail import EmailMultiAlternatives

from django.template.loader import render_to_string


def mail(subject, context, template, from_email, to_email, connection=None):
	html_template = render_to_string(template + '.html', context)
	txt_template = render_to_string(template + '.txt', context)

	plinper = pynliner.Pynliner()
	plinper.relative_url = 'file://localhost/'

	html_email = plinper.from_string(html_template).run()
	email = EmailMultiAlternatives(subject, txt_template, from_email, to_email)
	email.mixed_subtype = 'related'

	# Find all images in html
	img_regex = '<img(.*?)src=("|\')(.*?)("|\')(.*?)>'
	compiled_img_regex = re.compile(img_regex)
	images = compiled_img_regex.findall(html_email)

	# Replace src to cid
	for image in images:
		img_path = image[2]
		img_file = open(img_path , 'rb')
		img = MIMEImage(img_file.read())
		img_file.close()

		img_cid = hashlib.md5(open(img_path, 'rb').read()).hexdigest()
		img.add_header('Content-ID', '<%s>' % img_cid)
		img.add_header('Content-Disposition', 'inline')

		email.attach(img)
		html_email = re.sub(img_path, 'cid:%s' % img_cid , html_email)

	email.attach_alternative(html_email, "text/html")

	if connection:
		connection.open()

	email.send()



import base64
import mimetypes

from django import template


register = template.Library()


@register.filter()
def image2base64(image):
	if image:
		with open(image.path, 'rb') as image_bin:
			image_base64 = base64.b64encode(image_bin.read())

		image_mimetype = mimetypes.guess_type(image.path)[0]

		return 'data:%s;base64,%s' % (image_mimetype, image_base64)



from setuptools import setup, find_packages
# python setup.py register
# python setup.py sdist upload

setup(
	name="django-helpful",
	version="1.0.6",
	description="Django helpful things",
	long_description=open('README.rst').read(),
	author="Stanislav Baltrunas",
	author_email="stanislav@baltrunas.ru",
	license="BSD",
	url="https://github.com/Baltrunas/django-helpful",
	packages=find_packages(exclude=["tests.*", "tests"]),
	include_package_data=True,
	classifiers=[
		"Development Status :: 3 - Alpha",
		"Environment :: Web Environment",
		"Intended Audience :: Developers",
		"License :: OSI Approved :: BSD License",
		"Operating System :: OS Independent",
		"Programming Language :: Python",
		"Framework :: Django",
	],
	zip_safe=False,
)


from django import template


register = template.Library()


@register.simple_tag(takes_context=True)
def render(context, content):
	try:
		tpl = template.Template(content)
		content = template.Context(context)
		return tpl.render(content)
	except:
		return 'Render Error'



import urllib
import urllib2

from django.conf import settings


def urlencode(string):
	string = urllib.unquote(string)
	string = u'' + urllib.quote(string.encode('utf-8'))
	return string


def send_sms(text, phone=settings.SMS_TO):
	url = 'http://sms.ru/sms/send?api_id=%s&to=%s&text=%s&from=%s&translit=0' % (
		settings.SMS_KEY,
		urlencode(phone),
		urlencode(text),
		urlencode(settings.SMS_NAME)
	)
	urllib2.urlopen(url)
